from invoke import task
from . import create


@task
def sidney(ctx, name):
    """ all the jazz - creates everything."""
    from bluemax.sa import tasks as database

    create.project(ctx, name, with_config=True)
    create.tests(ctx, name)
    database.create(ctx, name)



"""
    An rpc concept for asyncio
"""
from .asyncpoolexecutor import AsyncPoolExecutor, NotRunningException
from .tasks.run import bring_up
from .rpc import ContextRpc
from .settings import get_settings

VERSION = "0.1.21"
name = "bluemax"
